pub trait GetProgram {
// Required method
fn get_program(&self, ca: &ContentAddress) -> Arc<Program>;
}Required Methods
Sourcefn get_program(&self, ca: &ContentAddress) -> Arc<Program>
fn get_program(&self, ca: &ContentAddress) -> Arc<Program>
Provides immediate access to the program with the given content address.
This is called by check_set_predicates for each node within each predicate for
each solution being checked.
All necessary programs are assumed to have been read from storage and validated ahead of time.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".